@@ -1,7 +1,7 @@
 package App::PMUtils;
 
-our $DATE = '2016-08-25'; # DATE
-our $VERSION = '0.61'; # VERSION
+our $DATE = '2016-10-11'; # DATE
+our $VERSION = '0.62'; # VERSION
 
 use 5.010001;
 
@@ -127,8 +127,8 @@ This is basically a shortcut for:
 
     % pmpath -Pd MODULE_OR_PREFIX_NAME
 
-Sometimes I forgot that `pmpath` has a `-d` option, and often intuitively look
-for a `pmdir` command.
+Sometimes I forgot that <prog:pmpath> has a `-d` option, and often intuitively
+look for a <prog:pmdir> command.
 
 _
     $meta->{args} = { %{ $SPEC{pmpath}{args} } }; # shalow copy
@@ -141,6 +141,38 @@ sub pmdir {
     pmpath(@_, prefix=>1, dir=>1);
 }
 
+$SPEC{rel2mod} = {
+    v => 1.1,
+    summary => 'Convert release name (e.g. Foo-Bar-1.23.tar.gz) to '.
+        'module name (Foo::Bar)',
+    args => {
+        releases => {
+            #'x.name.is_plural' => 1,
+            schema => ['array*', of=>'str*'],
+            req => 1,
+            pos => 0,
+            greedy => 1,
+            cmdline_src => 'stdin_or_args',
+        },
+    },
+    result_naked => 1,
+};
+sub rel2mod {
+    my %args = @_;
+
+    #use DD; dd \%args;
+
+    my @res;
+    for (@{ $args{releases} }) {
+        s!.+/!!; # remove directory path
+        s/-v?\d.+//;
+        s/-/::/g;
+        push @res, $_;
+    }
+
+    \@res;
+}
+
 1;
 # ABSTRACT: Command-line utilities related to Perl modules
 
@@ -156,7 +188,7 @@ App::PMUtils - Command-line utilities related to Perl modules
 
 =head1 VERSION
 
-This document describes version 0.61 of App::PMUtils (from Perl distribution App-PMUtils), released on 2016-08-25.
+This document describes version 0.62 of App::PMUtils (from Perl distribution App-PMUtils), released on 2016-10-11.
 
 =head1 SYNOPSIS
 
@@ -211,6 +243,8 @@ modules:
 
 =item * L<pwd2mod>
 
+=item * L<rel2mod>
+
 =back
 
 The main purpose of these utilities is tab completion.
@@ -226,8 +260,8 @@ This is basically a shortcut for:
 
  % pmpath -Pd MODULE_OR_PREFIX_NAME
 
-Sometimes I forgot that C<pmpath> has a C<-d> option, and often intuitively look
-for a C<pmdir> command.
+Sometimes I forgot that L<pmpath> has a C<-d> option, and often intuitively
+look for a L<pmdir> command.
 
 This function is not exported.
 
@@ -313,6 +347,23 @@ that contains extra information.
 
 Return value:  (any)
 
+
+=head2 rel2mod(%args) -> any
+
+Convert release name (e.g. Foo-Bar-1.23.tar.gz) to module name (Foo::Bar).
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<releases>* => I<array[str]>
+
+=back
+
+Return value:  (any)
+
 =head1 FAQ
 
 =for BEGIN_BLOCK: faq
